@@ -7,6 +7,7 @@ import subprocess
 import time
 
 from tronpytool import Tron
+from tronpytool.compile.paths import Paths
 from tronpytool.trx import Trx
 
 ROOT = os.path.join(os.path.dirname(__file__))
@@ -80,7 +81,7 @@ class SolcWrap(object):
     def workspace(self):
         return self.WORKSPACE_PATH
 
-    def StoreTxResult(self, tx_result_data, filepath):
+    def StoreTxResult(self, tx_result_data: any, filepath: str):
         self.writeFile(json.dumps(tx_result_data, ensure_ascii=False), filepath)
 
 
@@ -88,16 +89,15 @@ class CoreDeploy:
     """DEFI Contract deployment
     with the right strategies
     """
-    _contract_dict: dict
-    SUB_FIX = ""
-    ACTION_FOLDER = "deploy_results"
-    FILE_NAME = "deploy_{}{}.json"
 
     def __init__(self, tron: Tron):
         self.tron = tron
         self.last_class = ""
         self.list_type = "list_address"
         self._contract_dict = dict()
+        self.is_deploy = False
+        self.sol_cont = None
+        self.pathfinder = None
 
     @property
     def __list_key_label(self) -> str:
@@ -107,24 +107,6 @@ class CoreDeploy:
     def __kv_label(self) -> str:
         return "kv_{}".format(self.last_class)
 
-    @property
-    def subFix(self) -> str:
-        """preview the file name"""
-        return self.SUB_FIX
-
-    @subFix.setter
-    def subFix(self, sub: str) -> None:
-        """the file name does not require extension name"""
-        self.SUB_FIX = sub
-
-    @property
-    def deployed_record(self) -> str:
-        return self.FILE_NAME.format(self.tron.network_name, self.SUB_FIX)
-
-    @property
-    def deployedAddrsFilePath(self) -> str:
-        return os.path.join(self.sol_cont.workspace, self.ACTION_FOLDER, self.deployed_record)
-
     def getAddr(self, keyname: str) -> str:
         """example: TT67rPNwgmpeimvHUMVzFfKsjL9GZ1wGw8"""
         return self._contract_dict.get(keyname)
@@ -153,7 +135,7 @@ class CoreDeploy:
     def ready_io(self, show_address: bool = False):
         """try to load up the file from the existing path"""
         try:
-            self._contract_dict = json.load(codecs.open(self.deployedAddrsFilePath, 'r', 'utf-8-sig'))
+            self._contract_dict = self.pathfinder.LoadDeploymentFile()
             print("==== 🛄 data is prepared and it is ready now.. ")
             if show_address:
                 self.preview_all_addresses()
@@ -164,21 +146,34 @@ class CoreDeploy:
 
     def connect_deploy_core(self, workspace: str, rebuild=False, deploy=False) -> None:
         if rebuild:
-            sol_contr = SolcWrap(workspace).BuildRemote()
+            self.sol_cont = SolcWrap(workspace).BuildRemote()
         else:
-            sol_contr = SolcWrap(workspace)
-
+            self.sol_cont = SolcWrap(workspace)
+        self.pathfinder = Paths(workspace).setDefaultPath().Network(self.tron.network_name)
         self.is_deploy = deploy
-        self.sol_cont = sol_contr
 
         if not deploy:
             self.ready_io(True)
 
+    def connect(self, workspace: str, history: any) -> None:
+        self.is_deploy = False
+        self.sol_cont = SolcWrap(workspace)
+        if history is False:
+            self.pathfinder = Paths(workspace).setDefaultPath().Network(self.tron.network_name)
+        else:
+            self.pathfinder = Paths(workspace).SetUseVersion(history).Network(self.tron.network_name)
+
+        self.ready_io(True)
+
     def complete_deployment(self) -> None:
         """store up the deployed contrcat addresses to the local file storage"""
-        self.sol_cont.StoreTxResult(self._contract_dict, self.deployedAddrsFilePath)
+        self.sol_cont.StoreTxResult(self._contract_dict, self.pathfinder.SaveDeployConfig)
 
-    def deploy(self, sol_wrap: SolcWrap, classname: str, params: list = [], fee: int = 10 ** 9,
+    def deploy(self,
+               sol_wrap: SolcWrap,
+               classname: str,
+               params: list = [],
+               fee: int = 10 ** 9,
                percent: int = 1) -> str:
         """This is using the faster way to deploy files by using the specific abi and bin files"""
         _abi, _bytecode = sol_wrap.GetCodeClass(classname)
@@ -193,9 +188,8 @@ class CoreDeploy:
         sign = self.tron.trx.sign(tx_data)
         print("======== Signing {} ✅".format(classname))
         result = self.tron.trx.broadcast(sign)
-        path = "{}/{}.json".format(self.ACTION_FOLDER, classname)
-        print("======== Broadcast Result ✅ -> {}".format(path))
-        sol_wrap.StoreTxResult(result, path)
+        print("======== Broadcast Result ✅ -> {}".format(Paths.showCurrentDeployedClass(classname)))
+        sol_wrap.StoreTxResult(result, self.pathfinder.classObject(classname))
 
         if "transaction" not in result:
             print("failed to deploy contract with this error result from this.", result)
@@ -268,6 +262,15 @@ class CoreDeploy:
             return False
         return len(self._contract_dict[self.__list_key_label]) > 0
 
+    def hasField(self, key: str) -> bool:
+        if self.__kv_label not in self._contract_dict:
+            self._contract_dict[self.__kv_label] = dict()
+
+        if key not in self._contract_dict[self.__kv_label]:
+            return False
+        else:
+            return True
+
     def getString(self, key: str) -> str:
         return str(self.getVal(key))
 
@@ -309,14 +312,19 @@ class CoreDeploy:
         sign = self.tron.trx.sign(tx_data)
         print("======== Signing {} ✅".format(classname))
         result = self.tron.trx.broadcast(sign)
-        path = "{}/{}.json".format(self.ACTION_FOLDER, classname)
-        print("======== Broadcast Result ✅ -> {}".format(path))
-        sol_wrap.StoreTxResult(result, path)
+
+        print("======== Broadcast Result ✅ -> {}".format(Paths.showCurrentDeployedClass(classname)))
+        sol_wrap.StoreTxResult(result, self.pathfinder.classObject(classname))
+
         contract_address = self.tron.address.from_hex(result["transaction"]["contract_address"])
         self._contract_dict[classname] = contract_address
         print("======== address saved to ✅ {} -> {}".format(contract_address, classname))
         return contract_address
 
+    def _balanceOf(self, address: str) -> int:
+        amount = self.tron.trx.get_balance(address, False)
+        return amount
+
 
 class WrapContract(object):
     """docstring for WrapContract The contract for this BOBA TEA"""
@@ -344,35 +352,9 @@ class WrapContract(object):
         client = Tron().setNetwork(self._network)
         client.private_key = pri_key
         client.default_address = wallet_address
-
         return client
 
     def setMasterKey(self, pub: str, pri: str) -> "WrapContract":
         self.tron_client.private_key = pri
         self.tron_client.default_address = pub
         return self
-
-    def initContract(self, contract_metadata) -> "WrapContract":
-        """
-        Load and initiate contract interface by using the deployed contract json metadata
-        try:
-        except FileNotFoundError as e:
-            print("Could not load the file ", e)
-        except Exception as e:
-            print("Problems from loading items from the file: ", e)
-        """
-        contractDict = json.load(codecs.open(contract_metadata, 'r', 'utf-8-sig'))
-        trn = contractDict["transaction"]
-        hex_address = trn["contract_address"]
-        self.transction_detail = contractDict
-        self.trc_address = self.tron_client.address.from_hex(hex_address)
-        print("@contract address {} from hex {}".format(self.trc_address, hex_address))
-        # self.init_internal_contract()
-        self.implcontract()
-        return self
-
-    def getTxID(self):
-        return self.transction_detail["txid"]
-
-    def implcontract(self):
-        pass
